Mistral Dashboard Release Notes
===============================

Contents
========

.. toctree::
   :maxdepth: 2

   unreleased
   newton
   mitaka
   liberty


   Indices and tables
   ==================

   * :ref:`genindex`
     * :ref:`search`
